# Domain Adaptation and Generalization on Functional Medical Images: A Systematic Survey

This GitHub repository provides a systematic overview of novel domain adaptation and domain generalization methods on functional brain images. It contains a variety of resources and papers to help researchers and practitioners understand and apply these methods in their own projects. The repository also contains tables and references related to novel domain adaptation and generalization techniques, as well as a collection of related datasets. This repository is a valuable resource for anyone interested in exploring and exploiting the field of domain adaptation and domain generalization on functional brain images.

# Contents
* Table of papers
  * [EEG papers](tables/EEG%20papers.md)
  * [fMRI papers](tables/fMRI%20papers.md)
* Table of Datasets
  * [EEG datasets](tables/EEG%20datasets.md)
  * [fMRI datasets](tables/fMRI%20datasets.md)
* Figures
  * [Fig 1. Transfer Learning Categories](figures/transfer_learning_categories.pdf)
  * [Fig 2. Different Domain Adaptation (DA) scenarios based on label distribution](figures/DA_scenarios_labels.pdf)
  * [Fig 3. Distribution of related works on EEG data in recent years based on different domains](figures/EEG_domains_distributions.pdf)
  * [Fig 4. Distribution of related works on EEG data in recent years based on different tasks](figures/EEG_tasks_distributions.pdf)
  * [Fig 5. Distribution of related works on fMRI data in recent years based on different domains](figures/fMRI_domains_distributions.pdf)
  * [Fig 6. Distribution of related works on fMRI data in recent years based on different tasks](figures/fMRI_tasks_distributions.pdf)
  * [Fig 7. Hierarchy of different types of architecture used in recent works](figures/Hierarchy_Architecture.pdf)
  * [Fig 8. Hierarchy of different Domain Adaptation approaches used in recent works](figures/Hierarchy_DA.pdf)
  * [Fig 9. Hierarchy of different Domain Generalization approaches used in recent works](figures/Hierarchy_DG.pdf)


# Cite
[Arxiv version of paper](https://arxiv.org/abs/2212.03176):
```
@misc{https://doi.org/10.48550/arxiv.2212.03176,
  doi = {10.48550/ARXIV.2212.03176},
  url = {https://arxiv.org/abs/2212.03176},
  author = {Sarafraz, Gita and Behnamnia, Armin and Hosseinzadeh, Mehran and Balapour, Ali and Meghrazi, Amin and Rabiee, Hamid R.},
  keywords = {Image and Video Processing (eess.IV), Computer Vision and Pattern Recognition (cs.CV), Machine Learning (cs.LG), FOS: Electrical engineering, electronic engineering, information engineering, FOS: Electrical engineering, electronic engineering, information engineering, FOS: Computer and information sciences, FOS: Computer and information sciences},
  title = {Domain Adaptation and Generalization on Functional Medical Images: A Systematic Survey},
  publisher = {arXiv},
  year = {2022},
  copyright = {arXiv.org perpetual, non-exclusive license}
}
```
